@@ -12,6 +12,7 @@ import re
 from inspect import isfunction
 
 _group_pat=re.compile(r'\s*group ', re.I)
+_as_pat=re.compile(r'^(\w+)\s+as\s+(\w+)$', re.I)
 
 def _restrict(flds, coll):
     """private method for cleaning a set or dict of any items that aren't
@@ -25,8 +26,8 @@ def _restrict(flds, coll):
     def infld(thing, flds):
         if thing in flds:
             return True
-        if hasattr(thing, 'name'):
-            if thing.name in flds:
+        if hasattr(thing, 'asname'):
+            if thing.asname in flds:
                 return True
         return False
     
@@ -102,8 +103,15 @@ class _metapydo(type):
         for f in namespace.get('fields', ()):
             # support for tuple syntax for plain Jane fields.
             if isinstance(f, basestring):
-                simplefields.add(f)                
-                f=cls._create_field(f)
+                m=_as_pat.match(f)
+                if m:
+                    name=m.group(1)
+                    asname=m.group(2)
+                    simplefields.add(asname)
+                    f=cls._create_field(name=name, asname=asname)
+                else:
+                    simplefields.add(f)                
+                    f=cls._create_field(f)
             elif isinstance(f, dict):
                 f=cls._create_field(**f)
             elif isinstance(f, (tuple, list)):
@@ -112,7 +120,7 @@ class _metapydo(type):
                 raise ValueError, "cannot coerce into a field: %s" % f
                 
             # add to field container
-            fielddict[f.name]=f
+            fielddict[f.asname]=f
 
         # handle inheritance of fields and unique declarations.
         # skipping object and dict is a trivial optimization,
@@ -152,9 +160,9 @@ class _metapydo(type):
         cls._sequenced={}
         for f in cls._fields.itervalues():
             if f.sequence:
-                cls._sequenced[f.name] = f.sequence
+                cls._sequenced[f.asname] = f.sequence
             if f.unique:
-                uniqueset.add(frozenset((f.name,)))
+                uniqueset.add(frozenset((f.asname,)))
 
         cls._unique=frozenset(uniqueset)
 
@@ -251,16 +259,16 @@ class PyDO(dict):
         module=kwargs.get('module', None)
         s=[]
         for f in fields:
-            if isinstance(f, Field):
-                s.append(f.name.lower())
-            elif isinstance(f, basestring):
-                s.append(f.lower())
-            elif isinstance(f, tuple):
-                if not len(f):
-                    raise ValueError, "empty tuple in field list"
-                s.append(f[0].lower())
-            else:
-                raise ValueError, "weird thing in field list: %s" % f
+            if not isinstance(f, Field):
+                if isinstance(f, dict):
+                    f=cls._create_field(**f)
+                elif isinstance(f, (list, tuple)):
+                    f=cls._create_field(*f)
+                elif isinstance(f, basestring):
+                    f=cls._create_field(f)
+                else:
+                    raise ValueError, "weird thing in field list: %s" % f
+            s.append(f.asname.lower())
         s.sort()
         if kwargs:
             s.append('0')
@@ -382,7 +390,7 @@ class PyDO(dict):
         raise NotImplementedError, "PyDO classes don't implement setdefault()"
     
     @classmethod
-    def getColumns(cls, qualifier=None):
+    def getColumns(cls, qualifier=None, with_as=False):
         """Returns a list of all columns in this table, in no
         particular order.
 
@@ -392,11 +400,13 @@ class PyDO(dict):
         will be used.
         
         """
-        if not qualifier:
+        if qualifier and not isinstance(qualifier, basestring):
+            qualifier=cls.getTable()
+        if with_as:
+            return [x.get_column_expression(qualifier) for x in cls._fields.itervalues()]
+        elif not qualifier:
             return cls._fields.keys()
         else:
-            if not isinstance(qualifier, basestring):
-                qualifier=cls.getTable()
             return ["%s.%s" % (qualifier, x) for x in cls._fields.iterkeys()]
 
     @classmethod
@@ -420,8 +430,9 @@ class PyDO(dict):
         """a simple field validator that verifies that the keys
         in the dictionary passed are declared fields in the class.
         """
+        asnames=cls._fields
         for k in adict:
-            if not cls._fields.has_key(k):
+            if not k in asnames:
                 raise KeyError, "object %s has no field %s" %\
                       (cls, k)
 
@@ -581,7 +592,7 @@ class PyDO(dict):
     @classmethod
     def _baseSelect(cls, qualified=False):
         """returns the beginning of a select statement for this object's table."""
-        return 'SELECT %s FROM %s' % (', '.join(cls.getColumns(qualified)),
+        return 'SELECT %s FROM %s' % (', '.join(cls.getColumns(qualified, with_as=True)),
                                       cls.getTable())
 
 
