@@ -290,6 +290,18 @@ class test_project9(base_fixture):
         res=p1.getSome()
         assert len(res)==1
 
+
+class test_project10(base_fixture):
+    usetables=['E']
+    tags=alltags
+
+    def run(self):
+        p1=self.E.project('user1', dict(name='user2', asname='poop'))
+        cols=p1.getColumns()
+        assert len(cols)==2
+        assert 'user1' in cols
+        assert 'poop' in cols
+
 @tag(*alltags)
 def test_guess_tablename1():
     class base(P.PyDO):
@@ -346,7 +358,7 @@ def test_guess_columns1():
                                 frozenset(('id',))))
 
     finally:
-        if db.autocommit:
+        if db.autocommit or config.DRIVER == "sqlite2":
             c.execute('drop table test_guess_columns1')
         else:
             db.rollback()
@@ -404,7 +416,7 @@ class test_new1(Fixture):
         c.close()
 
     def cleanup(self):
-        if self.db.autocommit:
+        if self.db.autocommit or config.DRIVER == "sqlite2":
             c=self.db.cursor()
             c.execute('DROP TABLE test_new1')
             c.close()
@@ -577,8 +589,10 @@ class test_updateSome3(base_fixture):
         c.close()
 
     def run(self):
-
-        self.B.updateSome(dict(x=2000), "x < %s", 500)
+        if config.DRIVER == 'sqlite2':
+          self.B.updateSome(dict(x=2000), "x < ?", 500)
+        else:
+          self.B.updateSome(dict(x=2000), "x < %s", 500)
         sql='SELECT COUNT(*) FROM b WHERE x = 2000'
         c=self.db.cursor()
         c.execute(sql)
@@ -912,7 +926,10 @@ class test_one_to_many3(base_fixture):
     def run(self):
         tmp=self.ac1.getF(P.NE(P.FIELD('a_id'), 2))
         assert len(tmp)==4
-        tmp=self.ac1.getF("a_id > %s", 100)
+        if config.DRIVER == "sqlite2":
+          tmp=self.ac1.getF("a_id > ?", 100)
+        else:
+          tmp=self.ac1.getF("a_id > %s", 100)
         assert len(tmp)==0
         tmp=self.ac1.getF(a_id=4000)
         assert len(tmp)==0
@@ -961,9 +978,58 @@ class test_getCount1(base_fixture):
         assert c == 1
         c=self.D.getCount()
         assert c == 20
-        c=self.D.getCount("x < %s", 3)
+        if config.DRIVER == "sqlite2":
+          c=self.D.getCount("x < ?", 3)
+        else:
+          c=self.D.getCount("x < %s", 3)
         assert c == 3
         c=self.D.getCount(P.OR(P.EQ(P.FIELD('id'), 5), P.GT(P.FIELD('x'), 10)))
         assert c == 10
 
         
+class test_as1(base_fixture):
+    usetables=['E']
+    tags=alltags
+
+    def pre(self):
+        self.E.new(user1='me', user2='you')
+        self.E.new(user1='me', user2='gonga')
+        self.E.new(user1='bongo', user2='you')
+
+    def run(self):
+        o1=self.E.getUnique(id=1)
+        assert o1.user1=='me'
+        assert o1.user2=='you'
+        p=self.E.project('user1', P.Field('count(*)', asname='count'))
+        if config.DRIVER=='sqlite2':
+            res=p.getSome('user1=? group by user1', 'me')
+        else:
+            res=p.getSome('user1=%s group by user1', 'me')
+        #print res
+        assert len(res)==1
+        assert res[0].count==2
+        if config.DRIVER=='sqlite2':
+            res=p.getSome('user1 = ? group by user1', 'bongo')
+        else:
+            res=p.getSome('user1 = %s group by user1', 'bongo')
+        assert len(res)==1
+        assert res[0].count==1
+        
+
+        
+class test_as2(base_fixture):
+    usetables=['E']
+    tags=alltags
+
+    def run(self):
+        p=self.E.project('user1', P.Field(name='user3', asname='plapitude'))
+        #p=self.E.project('user1', 'user3 as plapitude')
+        cols=p.getColumns()
+        assert 'plapitude' in cols
+        assert 'user1' in cols
+        assert len(cols)==2
+        p2=self.E.project('user1', 'user3 as plapitude')
+        cols=p2.getColumns()
+        assert 'plapitude' in cols
+        assert 'user1' in cols
+        assert len(cols)==2
